#########################################################
## full replication file for "Who Controls the Content of 
##   Supreme Court Opinions?"
## Carrubba, Friedman, Martin, and Vanberg
## American Journal of Political Science
##
## ADM 3/7/2010
## ADM 12/31/2010
## ADM 9/13/2011

library(mvtnorm)
library(pscl)
library(apsrtable)
library(foreign)
library(xtable)
library(MCMCpack)

####################
## table 1
{
## load in data
analysis <- read.dta("../finalData/analysisTable1.dta", 
   convert.factors=FALSE, convert.underscore = TRUE)

## pull necessary variables
caseid <- analysis$caseid
justice <- analysis$justid
majority <- analysis$majority
mqscore <- analysis$mqscore
concur <- analysis$concur
psv <- analysis$is.psv

## loop over cases and create lists of necessary quantities
cases <- unique(caseid)
mq.hold <- justice.hold <- concur.hold <- majority.hold <- NULL

for(i in 1:length(cases)) {
   case <- cases[i]
   select <- caseid==case
   order <- order(mqscore[select])
   mq.hold[[i]] <- mqscore[select][order]
   justice.hold[[i]] <- justice[select][order] 
   concur.hold[[i]] <- concur[select][order]
   majority.hold[[i]] <- majority[select][order]
}

## form coalition indicators
coalition <- NULL
for(i in 1:length(cases)) {
   build <- majority.hold[[i]]
   if(!any(is.na(build)))
      coalition[i] <- paste(build[1], build[2], build[3], build[4], build[5],
         build[6], build[7], build[8], build[9], sep="")
   else coalition[i] <- NA
}

## form perfect spatial voting indicator
psv <- rep(FALSE, length(cases))
for(i in 1:length(cases)) {
  if(!is.na(coalition[i])) {
     if(coalition[i]=="111111111") psv[i] <- TRUE
     if(coalition[i]=="011111111") psv[i] <- TRUE   
     if(coalition[i]=="001111111") psv[i] <- TRUE
     if(coalition[i]=="000111111") psv[i] <- TRUE
     if(coalition[i]=="000011111") psv[i] <- TRUE
     if(coalition[i]=="111110000") psv[i] <- TRUE
     if(coalition[i]=="111111000") psv[i] <- TRUE
     if(coalition[i]=="111111100") psv[i] <- TRUE
     if(coalition[i]=="111111110") psv[i] <- TRUE     
  }
}

## create overall figure
psv.concur <- concur.hold[psv]
psv.coalition <- coalition[psv]

## do the tabulation for each justice position (1-9) for each coalition
position.tabulate <- function(coalition, psv.concur, psv.coalition) {
   hold <- rep(0,9)
   for(i in 1:length(psv.concur)) {
      if(psv.coalition[i]==coalition) hold <- hold + psv.concur[[i]]
   }
   return(hold)
}

## concurrent rate for perfect spatial voting, for common coalitions
## (unanimous, 7-2, 6-3, 5-4)

## 5-4 right coalition
five.four.right <- position.tabulate("000011111", psv.concur, psv.coalition)
five.four.right[1:4] <- NA

## 5-4 left coalition
five.four.left <- position.tabulate("111110000", psv.concur, psv.coalition)
five.four.left[6:9] <- NA

## 6-3 right coalition
six.three.right <- position.tabulate("000111111", psv.concur, psv.coalition)
six.three.right[1:3] <- NA

## 6-3 left coalition
six.three.left <- position.tabulate("111111000", psv.concur, psv.coalition)
six.three.left[7:9] <- NA

## 7-2 right coalition
seven.two.right <- position.tabulate("001111111", psv.concur, psv.coalition)
seven.two.right[1:2] <- NA

## 7-2 left coalition
seven.two.left <- position.tabulate("111111100", psv.concur, psv.coalition)
seven.two.left[8:9] <- NA

## 8-1 right coalition
eight.one.right <- position.tabulate("011111111", psv.concur, psv.coalition)
eight.one.right[1] <- NA

## 8-1 left coalition
eight.one.left <- position.tabulate("111111110", psv.concur, psv.coalition)
eight.one.left[9] <- NA

## concurrence rate in unanimous cases
unan <- position.tabulate("111111111", psv.concur, psv.coalition)

## pop out table of numbers
out.right <- data.frame(five.four.right, six.three.right, seven.two.right,
   eight.one.right, unan, row.names=paste("Justice", 1:9))

out.left <- data.frame(five.four.left, six.three.left, seven.two.left,
   eight.one.left, unan, row.names=paste("Justice", 1:9))

print(xtable(out.right, caption="Right coalitions for Table 1"))
print(xtable(out.left, caption="Left coalitions for Table 1"))
}

####################
## figure 4
{
##  Created by Andrew D. Martin on 2008-03-07.
##  Copyright (c) 2008. All rights reserved.
##
## 3/7/2008
## revised on 8/14/2008 for new covariate
analysis <- read.dta("../finalData/analysisFinal.dta", 
  convert.factors=FALSE, convert.underscore = TRUE)

##########################
## filter for analysis

##  drop those not in majority (drop NA first)
analysis <- analysis[!is.na(analysis$majority),]
analysis <- analysis[analysis$majority==1,]

## drop if not perfect spatial voting (or not)
analysis <- analysis[analysis$is.psv==1,]

## drop opinion writers (who can't concur)
analysis <- analysis[analysis$is.writer==0,]

## drop two missing concurrences
analysis <- analysis[!is.na(analysis$concur2),]

## attach(analysis)

##########################
## covariates

## spatial distance to opinion writer
dist2 <- analysis$mqscore - analysis$coalmed

#########################################################

bins <- 150
intervals <- co.intervals(dist2, bins, overlap=0)

x <- NULL
y <- NULL
y2 <- NULL

for(i in 1:nrow(intervals)) {
	x <- c(x, mean(intervals[i,]))
	keep <- analysis$concur[dist2 > intervals[i,1] & dist2 < intervals[i,2]]
    keep2 <- analysis$concur2[dist2 > intervals[i,1] & dist2 < intervals[i,2]]
	y <- c(y, sum(keep)/length(keep))
	y2 <- c(y2, sum(keep2)/length(keep2))	
}

pdf("visual.pdf",height=6, width=8)
par(mar=c(5.1, 4.1, 0.1, 0.1))
plot(x, y2, ylim=c(0,.26), col="red", ylab="Proportion of Concurrences", 
   xlab="Distance to Coalition Median [Justice - Coalition Median]")
points(x, y, pch=15)
lines(lowess(y~x), lwd=3)
lines(lowess(y2~x), col="red", lwd=3)

legend(-7, .03, col=c("black", "red"), c("Special", "Special and Regular"), lwd=3)
dev.off()
}

####################
## table 2
{
## additional analysis post-APSR
## ADM 9/25/2009
## 
## NOTE: some stuff in Stata
analysis <- read.dta("../finalData/analysisFinal.dta", 
  convert.factors=FALSE, convert.underscore = TRUE)

## Re-specification of special concurrence model: when majority is five or larger, and the 
## number of special concurrences reduces the majority to four or less, then the distance 
## covariate for that case is the opinion writer, not the coalition median.  It would be 
## really, really cool if this works out.
## 
## find plurality cases

cases <- unique(analysis$caseid)
plurality <- rep(NA, nrow(analysis))

for(i in cases) {
   maj <- analysis$majority[analysis$caseid==i]
   concur <- analysis$concur[analysis$caseid==i]	
   justices <- length(maj[!is.na(maj)])
 
   total.maj <- sum(maj, na.rm=TRUE)
   total.concur <- sum(concur, na.rm=TRUE)
 
##   cat("\njustices", justices, "\n")
##   cat("maj", maj, "total", total.maj, "\n")
##   cat("conc", concur, "total", total.concur, "\n")

   plurality[analysis$caseid==i] <- 0
   ## 6 majority is four
   if(justices==6 & ((total.maj - total.concur)<4) ) {
         plurality[analysis$caseid==i] <- 1
   } 
   ## 7 majority is four
   if(justices==7 & ((total.maj - total.concur)<4) ) {
         plurality[analysis$caseid==i] <- 1
   }
   ## 8 majority is five
   if(justices==8 & ((total.maj - total.concur)<5) ) {
         plurality[analysis$caseid==i] <- 1
   }
   ## 9 majority is five
   if(justices==9 & ((total.maj - total.concur)<5) ) {
      plurality[analysis$caseid==i] <- 1
   }
}
analysis$plurality <- plurality

###################################################
## filter for analysis (speical concurrences only)

##  drop those not in majority (drop NA first)
analysis <- analysis[!is.na(analysis$majority),]
analysis <- analysis[analysis$majority==1,]

## drop if not perfect spatial voting (or not)
analysis <- analysis[analysis$is.psv==1,]

## drop opinion writers (who can't concur)
analysis <- analysis[analysis$is.writer==0,]

## drop two missing concurrences
analysis <- analysis[!is.na(analysis$concur2),]

##########################
## covariates

## spatial distance to opinion writer
dist.coal <- abs(analysis$mqscore - analysis$coalmed)
dist.opinion <- abs(analysis$mqscore - analysis$writer.loc)
dist.median <- abs(analysis$mqscore - analysis$med.loc)

## plurality distance
dist.plurality <- dist.coal
dist.plurality[analysis$plurality==1] <- dist.opinion[analysis$plurality==1]

m1 <- glm(analysis$concur ~ dist.plurality, binomial(logit))
m2 <- glm(analysis$concur ~ dist.median, binomial(logit))
m3 <- glm(analysis$concur ~ dist.opinion, binomial(logit))

##########################
## models with both types of concurrences

m1s <- glm(analysis$concur2 ~ dist.plurality, binomial(logit))
m2s <- glm(analysis$concur2 ~ dist.median, binomial(logit))
m3s <- glm(analysis$concur2 ~ dist.opinion, binomial(logit))

print(apsrtable(m1,m2,m3,m1s,m2s,m3s,se="vcov", digits=3, align="center"))
write.dta(cbind(analysis, dist.coal, dist.opinion, dist.median, dist.plurality),
  "analysisFinalHold.dta")
}

##################
## figure 5
{
ruler <- seq(0,6,0.05)
beta <- coef(m1)
vcov <- vcov(m1)
pred <- 1 / (1 + exp(-beta[1] - beta[2]*ruler))

sims <- 5000
holder <- matrix(NA, sims, length(pred))
for(i in 1:sims) {
	beta.draw <- rmvnorm(1, mean=beta, sigma=vcov)
	holder[i,] <-  1 / (1 + exp(-beta.draw[1] - beta.draw[2]*ruler))
}

tops <- apply(holder,2,quantile,.975)
bottoms <- apply(holder,2,quantile,0.025)

## plot the findings
pdf("resultsfig.pdf", height=5, width=6)
par(mar=c(5.1, 4.1, 0.1, 0.1))
plot(ruler, pred, type="n", xlab="Absolute Distance to Opinion Coalition Median",
  ylab="Predicted Probability of Special Concurrence", ylim=c(0,.31))
lines(ruler, pred, lwd=6)
for(i in 1:sims) {
	lines(matrix(c(ruler[i],ruler[i],tops[i],bottoms[i]),2,2))
}
dev.off()
}
