##################################################################
## supplemental replication file for "Who Controls the Content of 
##   Supreme Court Opinions?"
## Carrubba, Friedman, Martin, and Vanberg
## American Journal of Political Science
##
## ADM 3/7/2010
## ADM 12/31/2010
## ADM 9/13/2011

library(mvtnorm)
library(pscl)
library(apsrtable)
library(foreign)
library(xtable)
library(MCMCpack)

####################
## other specifications
{
	analysis <- read.dta("../finalData/analysisFinal.dta", 
	  convert.factors=FALSE, convert.underscore = TRUE)

	## Re-specification of special concurrence model: when majority is five or larger, and the 
	## number of special concurrences reduces the majority to four or less, then the distance 
	## covariate for that case is the opinion writer, not the coalition median.  It would be 
	## really, really cool if this works out.
	## 
	## find plurality cases

	cases <- unique(analysis$caseid)
	plurality <- rep(NA, nrow(analysis))

	for(i in cases) {
	   maj <- analysis$majority[analysis$caseid==i]
	   concur <- analysis$concur[analysis$caseid==i]	
	   justices <- length(maj[!is.na(maj)])

	   total.maj <- sum(maj, na.rm=TRUE)
	   total.concur <- sum(concur, na.rm=TRUE)

	##   cat("\njustices", justices, "\n")
	##   cat("maj", maj, "total", total.maj, "\n")
	##   cat("conc", concur, "total", total.concur, "\n")

	   plurality[analysis$caseid==i] <- 0
	   ## 6 majority is four
	   if(justices==6 & ((total.maj - total.concur)<4) ) {
	         plurality[analysis$caseid==i] <- 1
	   } 
	   ## 7 majority is four
	   if(justices==7 & ((total.maj - total.concur)<4) ) {
	         plurality[analysis$caseid==i] <- 1
	   }
	   ## 8 majority is five
	   if(justices==8 & ((total.maj - total.concur)<5) ) {
	         plurality[analysis$caseid==i] <- 1
	   }
	   ## 9 majority is five
	   if(justices==9 & ((total.maj - total.concur)<5) ) {
	      plurality[analysis$caseid==i] <- 1
	   }
	}
	analysis$plurality <- plurality

	###################################################
	## filter for analysis (speical concurrences only)

	##  drop those not in majority (drop NA first)
	analysis <- analysis[!is.na(analysis$majority),]
	analysis <- analysis[analysis$majority==1,]

	## drop if not perfect spatial voting (or not)
	analysis <- analysis[analysis$is.psv==1,]

	## drop opinion writers (who can't concur)
	analysis <- analysis[analysis$is.writer==0,]

	## drop two missing concurrences
	analysis <- analysis[!is.na(analysis$concur2),]

	##########################
	## covariates

	## spatial distance to opinion writer
	dist.coal <- abs(analysis$mqscore - analysis$coalmed)
	dist.opinion <- abs(analysis$mqscore - analysis$writer.loc)
	dist.median <- abs(analysis$mqscore - analysis$med.loc)

	## plurality distance
	dist.plurality <- dist.coal
	dist.plurality[analysis$plurality==1] <- dist.opinion[analysis$plurality==1]

	#############################################
	## other models

	m1 <- glm(analysis$concur ~ dist.opinion, binomial(logit))
	m2 <- glm(analysis$concur ~ dist.coal, binomial(logit))
    m3 <- glm(analysis$concur ~ dist.opinion+dist.coal+dist.median, binomial(logit))
	m4 <- glm(analysis$concur2 ~ dist.opinion, binomial(logit))
	m5 <- glm(analysis$concur2 ~ dist.coal, binomial(logit))
    m6 <- glm(analysis$concur2 ~ dist.opinion+dist.coal+dist.median, binomial(logit))


	print(apsrtable(m1,m2,m3,m4,m5,m6,se="vcov", digits=3, align="center"))
}

####################
## Georg's model [split to see if pooling driving finding]
{
m1 <- glm(analysis$concur[analysis$plurality==1] ~ dist.plurality[analysis$plurality==1], binomial(logit))
m2 <- glm(analysis$concur[analysis$plurality==0] ~ dist.plurality[analysis$plurality==0], binomial(logit))
m3 <- glm(analysis$concur2[analysis$plurality==1] ~ dist.plurality[analysis$plurality==1], binomial(logit))
m4 <- glm(analysis$concur2[analysis$plurality==0] ~ dist.plurality[analysis$plurality==0], binomial(logit))
print(apsrtable(m1,m2,m3,m4,se="vcov", digits=3, align="center"))
}

####################
## Cliff's model
{
m1 <- glm(analysis$concur[analysis$plurality==1] ~ dist.opinion[analysis$plurality==1] + dist.coal[analysis$plurality==1], binomial(logit))
m2 <- glm(analysis$concur[analysis$plurality==0] ~ dist.opinion[analysis$plurality==0] + dist.coal[analysis$plurality==0], binomial(logit))
m3 <- glm(analysis$concur2[analysis$plurality==1] ~ dist.opinion[analysis$plurality==1] + dist.coal[analysis$plurality==1], binomial(logit))
m4 <- glm(analysis$concur2[analysis$plurality==0] ~ dist.opinion[analysis$plurality==0] + dist.coal[analysis$plurality==0], binomial(logit))
print(apsrtable(m1,m2,m3,m4,se="vcov", digits=3, align="center"))
}

####################
## Bayes factor stuff
{
load("posteriors.Rda")
bf <- BayesFactor(new, median, coalition, opinion)
print(bf$BF.log.mat)
print(bf$BF.logmarglike)
}

####################
## models excluding unanimous cases
{
	#############################################
	## models excluding unimous cases

	nonunan <- !analysis$coal.type=="111111111"

	m1 <- glm(analysis$concur[nonunan] ~ dist.plurality[nonunan], binomial(logit))
	m2 <- glm(analysis$concur[nonunan] ~ dist.median[nonunan], binomial(logit))

	##########################
	## models with both types of concurrences

	m1s <- glm(analysis$concur2[nonunan] ~ dist.plurality[nonunan], binomial(logit))
	m2s <- glm(analysis$concur2[nonunan] ~ dist.median[nonunan], binomial(logit))

	print(apsrtable(m1,m2,m1s,m2s,se="vcov", digits=3, align="center"))
}

####################
## models excluding 5-4 cases
{
ff <- !(analysis$coal.type=="000011111"|analysis$coal.type=="111110000")

m1 <- glm(analysis$concur[ff] ~ dist.plurality[ff], binomial(logit))
m2 <- glm(analysis$concur[ff] ~ dist.median[ff], binomial(logit))

##########################
## models with both types of concurrences

m1s <- glm(analysis$concur2[ff] ~ dist.plurality[ff], binomial(logit))
m2s <- glm(analysis$concur2[ff] ~ dist.median[ff], binomial(logit))

print(apsrtable(m1,m2,m1s,m2s,se="vcov", digits=3, align="center"))
}

####################
## models excluding unanimous and 5-4 cases
{
both <- !(analysis$coal.type=="000011111"|analysis$coal.type=="111110000"|analysis$coal.type=="111111111")

m1 <- glm(analysis$concur[both] ~ dist.plurality[both], binomial(logit))
m2 <- glm(analysis$concur[both] ~ dist.median[both], binomial(logit))

##########################
## models with both types of concurrences

m1s <- glm(analysis$concur2[both] ~ dist.plurality[both], binomial(logit))
m2s <- glm(analysis$concur2[both] ~ dist.median[both], binomial(logit))

print(apsrtable(m1,m2,m1s,m2s,se="vcov", digits=3, align="center"))
	
}


####################
## georg's garbage model
m1 <- glm(analysis$concur ~ dist.coal + dist.opinion + dist.median, binomial(logit))
m1s <- glm(analysis$concur2 ~ dist.coal + dist.opinion + dist.median, binomial(logit))
print(apsrtable(m1,m1s,se="vcov", digits=3, align="center"))

###################
## including dockets main table

analysis <- read.dta("../finalData/analysisFinalDocket.dta", 
  convert.factors=FALSE, convert.underscore = TRUE)

## Re-specification of special concurrence model: when majority is five or larger, and the 
## number of special concurrences reduces the majority to four or less, then the distance 
## covariate for that case is the opinion writer, not the coalition median.  It would be 
## really, really cool if this works out.
## 
## find plurality cases

cases <- unique(analysis$caseid)
plurality <- rep(NA, nrow(analysis))

for(i in cases) {
   maj <- analysis$majority[analysis$caseid==i]
   concur <- analysis$concur[analysis$caseid==i]	
   justices <- length(maj[!is.na(maj)])
 
   total.maj <- sum(maj, na.rm=TRUE)
   total.concur <- sum(concur, na.rm=TRUE)
 
##   cat("\njustices", justices, "\n")
##   cat("maj", maj, "total", total.maj, "\n")
##   cat("conc", concur, "total", total.concur, "\n")

   plurality[analysis$caseid==i] <- 0
   ## 6 majority is four
   if(justices==6 & ((total.maj - total.concur)<4) ) {
         plurality[analysis$caseid==i] <- 1
   } 
   ## 7 majority is four
   if(justices==7 & ((total.maj - total.concur)<4) ) {
         plurality[analysis$caseid==i] <- 1
   }
   ## 8 majority is five
   if(justices==8 & ((total.maj - total.concur)<5) ) {
         plurality[analysis$caseid==i] <- 1
   }
   ## 9 majority is five
   if(justices==9 & ((total.maj - total.concur)<5) ) {
      plurality[analysis$caseid==i] <- 1
   }
}
analysis$plurality <- plurality

###################################################
## filter for analysis (speical concurrences only)

##  drop those not in majority (drop NA first)
analysis <- analysis[!is.na(analysis$majority),]
analysis <- analysis[analysis$majority==1,]

## drop if not perfect spatial voting (or not)
analysis <- analysis[analysis$is.psv==1,]

## drop opinion writers (who can't concur)
analysis <- analysis[analysis$is.writer==0,]

## drop two missing concurrences
analysis <- analysis[!is.na(analysis$concur2),]

##########################
## covariates

## spatial distance to opinion writer
dist.coal <- abs(analysis$mqscore - analysis$coalmed)
dist.opinion <- abs(analysis$mqscore - analysis$writer.loc)
dist.median <- abs(analysis$mqscore - analysis$med.loc)

## plurality distance
dist.plurality <- dist.coal
dist.plurality[analysis$plurality==1] <- dist.opinion[analysis$plurality==1]

m1 <- glm(analysis$concur ~ dist.plurality, binomial(logit), data=analysis)
m2 <- glm(analysis$concur ~ dist.median, binomial(logit), data=analysis)
m3 <- glm(analysis$concur ~ dist.opinion, binomial(logit), data=analysis)

##########################
## models with both types of concurrences

m1s <- glm(analysis$concur2 ~ dist.plurality, binomial(logit), data=analysis)
m2s <- glm(analysis$concur2 ~ dist.median, binomial(logit), data=analysis)
m3s <- glm(analysis$concur2 ~ dist.opinion, binomial(logit), data=analysis)

print(apsrtable(m1,m2,m3,m1s,m2s,m3s,se="vcov", digits=3, align="center"))

####################
## models including non-perfect spatial voting cases
{
	analysis <- read.dta("../finalData/analysisFinalNoPsv.dta", 
	  convert.factors=FALSE, convert.underscore = TRUE)

	## Re-specification of special concurrence model: when majority is five or larger, and the 
	## number of special concurrences reduces the majority to four or less, then the distance 
	## covariate for that case is the opinion writer, not the coalition median.  It would be 
	## really, really cool if this works out.
	## 
	## find plurality cases

	cases <- unique(analysis$caseid)
	plurality <- rep(NA, nrow(analysis))

	for(i in cases) {
	   maj <- analysis$majority[analysis$caseid==i]
	   concur <- analysis$concur[analysis$caseid==i]	
	   justices <- length(maj[!is.na(maj)])

	   total.maj <- sum(maj, na.rm=TRUE)
	   total.concur <- sum(concur, na.rm=TRUE)

	##   cat("\njustices", justices, "\n")
	##   cat("maj", maj, "total", total.maj, "\n")
	##   cat("conc", concur, "total", total.concur, "\n")

	   plurality[analysis$caseid==i] <- 0
	   ## 6 majority is four
	   if(justices==6 & ((total.maj - total.concur)<4) ) {
	         plurality[analysis$caseid==i] <- 1
	   } 
	   ## 7 majority is four
	   if(justices==7 & ((total.maj - total.concur)<4) ) {
	         plurality[analysis$caseid==i] <- 1
	   }
	   ## 8 majority is five
	   if(justices==8 & ((total.maj - total.concur)<5) ) {
	         plurality[analysis$caseid==i] <- 1
	   }
	   ## 9 majority is five
	   if(justices==9 & ((total.maj - total.concur)<5) ) {
	      plurality[analysis$caseid==i] <- 1
	   }
	}
	analysis$plurality <- plurality

	###################################################
	## filter for analysis (speical concurrences only)

	##  drop those not in majority (drop NA first)
	analysis <- analysis[!is.na(analysis$majority),]
	analysis <- analysis[analysis$majority==1,]

	## drop opinion writers (who can't concur)
	analysis <- analysis[analysis$is.writer==0,]

	## drop two missing concurrences
	analysis <- analysis[!is.na(analysis$concur2),]

	##########################
	## covariates

	## spatial distance to opinion writer
	dist.coal <- abs(analysis$mqscore - analysis$coalmed)
	dist.opinion <- abs(analysis$mqscore - analysis$writer.loc)
	dist.median <- abs(analysis$mqscore - analysis$med.loc)

	## plurality distance
	dist.plurality <- dist.coal
	dist.plurality[analysis$plurality==1] <- dist.opinion[analysis$plurality==1]
   
    ## fix cases when these can't be computed
    drop <- is.na(dist.median) | is.na(dist.plurality)

	analysis <- analysis[!drop,]
	dist.plurality <- dist.plurality[!drop]
	dist.median <- dist.median[!drop]

	m1 <- glm(analysis$concur ~ dist.plurality, binomial(logit))
	m2 <- glm(analysis$concur ~ dist.median, binomial(logit))

	##########################
	## models with both types of concurrences

	m1s <- glm(analysis$concur2 ~ dist.plurality, binomial(logit))
	m2s <- glm(analysis$concur2 ~ dist.median, binomial(logit))

	print(apsrtable(m1,m2,m1s,m2s,se="vcov", digits=3, align="center"))
	
}

####################
## other constitutional interaction
	analysis <- read.dta("../finalData/analysisFinal.dta", 
	  convert.factors=FALSE, convert.underscore = TRUE)

	## Re-specification of special concurrence model: when majority is five or larger, and the 
	## number of special concurrences reduces the majority to four or less, then the distance 
	## covariate for that case is the opinion writer, not the coalition median.  It would be 
	## really, really cool if this works out.
	## 
	## find plurality cases

	cases <- unique(analysis$caseid)
	plurality <- rep(NA, nrow(analysis))

	for(i in cases) {
	   maj <- analysis$majority[analysis$caseid==i]
	   concur <- analysis$concur[analysis$caseid==i]	
	   justices <- length(maj[!is.na(maj)])

	   total.maj <- sum(maj, na.rm=TRUE)
	   total.concur <- sum(concur, na.rm=TRUE)

	##   cat("\njustices", justices, "\n")
	##   cat("maj", maj, "total", total.maj, "\n")
	##   cat("conc", concur, "total", total.concur, "\n")

	   plurality[analysis$caseid==i] <- 0
	   ## 6 majority is four
	   if(justices==6 & ((total.maj - total.concur)<4) ) {
	         plurality[analysis$caseid==i] <- 1
	   } 
	   ## 7 majority is four
	   if(justices==7 & ((total.maj - total.concur)<4) ) {
	         plurality[analysis$caseid==i] <- 1
	   }
	   ## 8 majority is five
	   if(justices==8 & ((total.maj - total.concur)<5) ) {
	         plurality[analysis$caseid==i] <- 1
	   }
	   ## 9 majority is five
	   if(justices==9 & ((total.maj - total.concur)<5) ) {
	      plurality[analysis$caseid==i] <- 1
	   }
	}
	analysis$plurality <- plurality

	###################################################
	## filter for analysis (speical concurrences only)

	##  drop those not in majority (drop NA first)
	analysis <- analysis[!is.na(analysis$majority),]
	analysis <- analysis[analysis$majority==1,]

	## drop if not perfect spatial voting (or not)
	analysis <- analysis[analysis$is.psv==1,]

	## drop opinion writers (who can't concur)
	analysis <- analysis[analysis$is.writer==0,]

	## drop two missing concurrences
	analysis <- analysis[!is.na(analysis$concur2),]

	##########################
	## covariates

	## spatial distance to opinion writer
	dist.coal <- abs(analysis$mqscore - analysis$coalmed)
	dist.opinion <- abs(analysis$mqscore - analysis$writer.loc)
	dist.median <- abs(analysis$mqscore - analysis$med.loc)

	## plurality distance
	dist.plurality <- dist.coal
	dist.plurality[analysis$plurality==1] <- dist.opinion[analysis$plurality==1]

	#############################################
	## other models

	m1 <- glm(analysis$concur ~ dist.coal*analysis$conchal, binomial(logit))
	m2 <- glm(analysis$concur2 ~ dist.coal*analysis$conchal, binomial(logit))


	print(apsrtable(m1,m2,se="vcov", digits=3, align="center"))


